@@ -9,8 +9,8 @@
 
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; Keywords: convenience
-;; Package-Version: 20260106.250
-;; Package-Revision: e5357f318eae
+;; Package-Version: 20260108.1320
+;; Package-Revision: a08e8774e757
 ;; URL: https://codeberg.org/ideasman42/emacs-repeat-fu
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -63,7 +63,7 @@ By convention, the following rules are followed for bundled presets.
   :type 'symbol)
 
 (defcustom repeat-fu-global-mode t
-  "When true, `repeat-fu' shares its command buffer between buffers."
+  "When non-nil, `repeat-fu' shares its command buffer between buffers."
   :type 'boolean)
 
 (defcustom repeat-fu-last-used-on-quit t
